# inspect-nn : simPle sImulator for Neural nEtworks using APProximate muLtipliErs (written in python)

inspect-nn is a simulation tool for measuring the classification accuracy loss due to the use of approximate multipliers (i.e., multipliers designed by exploiting the [approximate computing design paradigm](https://link.springer.com/book/10.1007/978-3-030-94705-7)) in neural networks. 

It has been developed to easily do porting of keras/tensorflow models, and to use the GPU to simulate a neural network while using approximate arithmetic units quickly and almost effortlessly. 

Anyway, it is still under development!

## Installing the module
You can install this module using ```pip```
```bash
$ pip install inspect-nn
```

## Using inspect-nn



